@@ -14,16 +14,21 @@ public:
     ~SpeedoMeter();
     Ui::SpeedoMeter *ui;
     int unit;
+    int hour,min,sec,tensofsec;
+    int started,paused;
 
 protected:
     void changeEvent(QEvent *e);
 
 
 private slots:
+    void on_pauseTimeButton_clicked();
+    void on_startTimeButton_clicked();
     void on_pushButton_2_clicked();
     void on_pushButton_clicked();
 public slots:
     void start_gps();
+    void updateLocation();
     void updateTime();
 };
 
